Tasks and context relevant for building and running on any platform.
Structs
- Dependency
- Dependency that must be installed.
- Dependency
Check - Check that will be used to determine if a dependency is installed.
- Install
Dependencies - This task checks if all dependencies exist and if necessary, installs the dependencies that weren’t found.
- Install
Target - This task installs a target with the given name using rustup, if necessary.