serve

Function serve 

pub fn serve(device: Device) -> (SocketAddr, Disposable)
Starts a test feedback server for the given device. This function returns the address (incl. port) that the server is bound to, and a disposable that can be dropped to stop the server.