[−][src]Module polyhorn_cli::commands
Implementations for platform-independent Polyhorn-cli commands.
Structs
| Init | Creates a new Polyhorn app in the given directory. |
| Run | Runs the app on a device or simulator. |
Enums
| Platform | Represents a choice between one of the supported platforms that Polyhorn apps can be built for. |