Tasks and types for iOS-specific operations.
Modules
- commands
- iOS-specific implementations of Polyhorn CLI commands.
- infoplist
- Types to work with info plists that are used on iOS to convey metadata of an application. Note: the documentation of this module is taken directly from Apple.
- tasks
- Tasks and context specific for building and running on iOS.
- xcassets
- Types that represent the data structures of the
xcassetsformat. - xcodegen
- Rust-wrapper around the third-party
xcodegenutility (installed through Homebrew) that makes it possible to generate Xcode project files programmatically. Note: the documentation within this module is taken directly from the original excellent documentation ofxcodegen.
Structs
- Spec
- Contains iOS-specific settings within an app specification stored in a
Polyhorn.tomlfile.