[][src]Module polyhorn_cli::ios

Tasks and types for iOS-specific operations.

Modules

commands

iOS-specific implementations of Polyhorn CLI commands.

infoplist

Types to work with info plists that are used on iOS to convey metadata of an application. Note: the documentation of this module is taken directly from Apple.

simctl

Rust-wrapper around the simctl utility that is shipped with Xcode and that can be used to install apps onto one of the iOS simulator and subsequently launch them.

xcassets

Types that represent the data structures of the xcassets format.

xcodegen

Rust-wrapper around the third-party xcodegen utility (installed through Homebrew) that makes it possible to generate Xcode project files programmatically. Note: the documentation within this module is taken directly from the original excellent documentation of xcodegen.

Structs

Spec

Contains iOS-specific settings within an app specification stored in a Polyhorn.toml file.