[−][src]Module polyhorn_cli::ios
Tasks and types for iOS-specific operations.
Modules
| commands | iOS-specific implementations of Polyhorn CLI commands. |
| infoplist | Types to work with info plists that are used on iOS to convey metadata of an application. Note: the documentation of this module is taken directly from Apple. |
| simctl | Rust-wrapper around the |
| xcassets | Types that represent the data structures of the |
| xcodegen | Rust-wrapper around the third-party |
Structs
| Spec | Contains iOS-specific settings within an app specification stored in a
|